import { NextRequest, NextResponse } from 'next/server';
import { IncomingMessage, ServerResponse } from 'http';

declare type AuthCredentialsObject = {
    name: string;
    password: string;
};
declare type AuthCredentials = AuthCredentialsObject[];

type MiddlewareOptions = {
  realm?: string
  users?: AuthCredentials
  includePaths?: string[]
  excludePaths?: string[]
}

/**
 * Creates a default Next middleware function that returns `NextResponse.next()` if the basic auth passes
 * @param req Next middleware request
 * @param options Options object based on MiddlewareOptions
 * @returns Either a 401 error or goes to the next page
 */
declare const createNextAuthMiddleware: ({ realm, users, includePaths, excludePaths, }?: MiddlewareOptions) => (req: NextRequest) => NextResponse;
declare const nextBasicAuthMiddleware: ({ realm, users, includePaths, excludePaths, }: MiddlewareOptions | undefined, req: NextRequest) => NextResponse;

/**
 * Middleware that sends a basic auth challenge to the user when enabled.
 * For use in `getServerSideProps` requests
 * @param req Http server incoming message
 * @param res Server response
 */
declare const serverMiddleware: (req: IncomingMessage, res: ServerResponse, { realm, users, includePaths, excludePaths, }?: MiddlewareOptions) => void;

export { MiddlewareOptions, createNextAuthMiddleware, nextBasicAuthMiddleware, serverMiddleware };
