"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  createNextAuthMiddleware: () => createNextAuthMiddleware,
  nextBasicAuthMiddleware: () => nextBasicAuthMiddleware,
  serverMiddleware: () => serverMiddleware
});
module.exports = __toCommonJS(src_exports);

// src/nextMiddleware.ts
var import_server = require("next/server");

// src/lib/auth.ts
function basicAuthentication(authorization) {
  if (!authorization) {
    return void 0;
  }
  const [scheme, encoded] = authorization.split(" ");
  if (!encoded || scheme !== "Basic") {
    throw new BadRequestException("Malformed authorization header.");
  }
  const buffer = Uint8Array.from(
    atob(encoded),
    (character) => character.charCodeAt(0)
  );
  const decoded = new TextDecoder().decode(buffer).normalize();
  const index = decoded.indexOf(":");
  if (index === -1 || /[\0-\x1F\x7F]/.test(decoded)) {
    throw new BadRequestException("Invalid authorization value.");
  }
  return {
    user: decoded.substring(0, index),
    pass: decoded.substring(index + 1)
  };
}
var BadRequestException = class extends Error {
  status;
  statusText;
  reason;
  constructor(reason) {
    super(reason);
    this.status = 400;
    this.statusText = "Bad Request";
    this.reason = reason;
  }
};

// src/lib/compare.ts
var safeCompare = (a, b) => {
  const stringA = String(a);
  const lengthA = stringA.length;
  let stringB = String(b);
  let result = 0;
  if (lengthA !== stringB.length) {
    stringB = stringA;
    result = 1;
  }
  for (let i = 0; i < lengthA; i++) {
    result |= stringA.charCodeAt(i) ^ stringB.charCodeAt(i);
  }
  return result === 0;
};

// src/lib/credentials.ts
var parseCredentials = (credentials) => {
  const authCredentials = [];
  credentials.split("|").forEach((item) => {
    if (item.length < 3) {
      throw new Error(
        `Received incorrect basic auth syntax, use <username>:<password>, received ${item}`
      );
    }
    const parsedCredentials = item.split(":");
    if (parsedCredentials[0].length === 0 || parsedCredentials[1].length === 0) {
      throw new Error(
        `Received incorrect basic auth syntax, use <username>:<password>, received ${item}`
      );
    }
    authCredentials.push({
      name: parsedCredentials[0],
      password: parsedCredentials[1]
    });
  });
  return authCredentials;
};
var compareCredentials = (input, requiredCredentials) => requiredCredentials.some(
  (item) => safeCompare(input.user, item.name) && safeCompare(input.pass, item.password)
);

// src/lib/path.ts
var pathInRequest = (paths, req) => {
  if (req.url === void 0) {
    return false;
  }
  const path = new URL(req.url).pathname;
  return paths.some((item) => path == null ? void 0 : path.startsWith(item));
};

// src/nextMiddleware.ts
var createNextAuthMiddleware = ({
  realm = "protected",
  users = [],
  includePaths = ["/"],
  excludePaths = []
} = {}) => (req) => nextBasicAuthMiddleware({ realm, users, includePaths, excludePaths }, req);
var nextBasicAuthMiddleware = ({
  realm = "protected",
  users = [],
  includePaths = ["/"],
  excludePaths = []
} = {}, req) => {
  const environmentCredentials = process.env.BASIC_AUTH_CREDENTIALS || "";
  if (environmentCredentials.length === 0 && users.length === 0) {
    return import_server.NextResponse.next();
  }
  const includeAuth = process.env.BASIC_AUTH_PATHS ? process.env.BASIC_AUTH_PATHS.split(";") : includePaths;
  const excludeAuth = process.env.BASIC_AUTH_EXCLUDE_PATHS ? process.env.BASIC_AUTH_EXCLUDE_PATHS.split(";") : excludePaths;
  if (pathInRequest(excludeAuth, req) || !pathInRequest(includeAuth, req)) {
    return import_server.NextResponse.next();
  }
  const credentialsObject = environmentCredentials.length > 0 ? parseCredentials(environmentCredentials) : users;
  const authHeader = req.headers.get("authorization");
  if (authHeader) {
    const currentUser = basicAuthentication(authHeader);
    if (currentUser && compareCredentials(currentUser, credentialsObject)) {
      return import_server.NextResponse.next();
    }
  }
  return import_server.NextResponse.next({
    status: 401,
    headers: {
      "WWW-Authenticate": `Basic realm="${realm}"`
    }
  });
};

// src/serverMiddleware.ts
var serverMiddleware = (req, res, {
  realm = "protected",
  users = [],
  includePaths = ["/"],
  excludePaths = []
} = {}) => {
  if (!(req == null ? void 0 : req.url)) {
    return;
  }
  const environmentCredentials = process.env.BASIC_AUTH_CREDENTIALS || "";
  if (environmentCredentials.length === 0 && users.length === 0) {
    return;
  }
  const includeAuth = process.env.BASIC_AUTH_PATHS ? process.env.BASIC_AUTH_PATHS.split(";") : includePaths;
  const excludeAuth = process.env.BASIC_AUTH_EXCLUDE_PATHS ? process.env.BASIC_AUTH_EXCLUDE_PATHS.split(";") : excludePaths;
  if (pathInRequest(excludeAuth, req) || !pathInRequest(includeAuth, req)) {
    return;
  }
  const credentialsObject = environmentCredentials.length > 0 ? parseCredentials(environmentCredentials) : users;
  const currentUser = basicAuthentication(req.headers.authorization);
  if (!currentUser || !compareCredentials(currentUser, credentialsObject)) {
    res.statusCode = 401;
    res.setHeader("WWW-Authenticate", `Basic realm="${realm}"`);
    res.end("401 Access Denied");
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  createNextAuthMiddleware,
  nextBasicAuthMiddleware,
  serverMiddleware
});
//# sourceMappingURL=index.js.map